{% extends "fa/foneastra_base.html" %}
{% load i18n %}
{% block title %}{% trans "Goodbye" %}{% endblock %}

{% block page_stylesheets %}
<style>
    #branding h1 {
            background: url("/media/images/CSElogoText_65.png") no-repeat 100% 50%;
    }

    #branding h1 b {
        height: 65px;
        display: block;
        text-indent: -9999px;
        background: url("/media/images/foneastra.png") no-repeat 0 50%;
    }

    .scform ul.errorlist { list-style-type: none; color:red; margin: 0; padding: 0;}
</style>
{% endblock %}

{% block content %}

<h1>{% trans "Thanks for using FoneAstra" %}</h1>

<p>{% trans "Please come again." %}</p>

<a href="/fa/login">{% trans "Log in again" %}</a>

{% endblock %}
