{% extends "fa/foneastra_base.html" %}
{% load foneastratags %}
{% load i18n %}

{% block title %}{% trans "FoneAstra" %}{% endblock %}

{% block content %}
<div class="module">
    <div class="top">
        <h2>Welcome to FoneAstra</h2>
        <p>Welcome to FoneAstra!  Installed projects are listed at the top
        right.</p>
    </div>
</div>
{% endblock %}
