/* vim:set et ts=4 sw=4 */


.col-1, .col-2, .col-3, .col-4, .col-5, .col-6 {
    margin-left: 1em;
    min-height: 1px;
    float: left;
}


.two-columns        { padding-left: 1em; }
.two-columns .col-1 { margin-left: -1em; }

    .two-columns .col-1,
    .two-columns .col-2 {
        width: 50%; }


.three-columns        { padding-left: 2em; }
.three-columns .col-1 { margin-left: -2em; }

    .three-columns .col-2 {
        width: 34%; }

    .three-columns .col-1,
    .three-columns .col-3 {
        width: 33%; }


.four-columns        { padding-left: 3em; }
.four-columns .col-1 { margin-left: -3em; }

    .four-columns .col-1,
    .four-columns .col-2,
    .four-columns .col-3,
    .four-columns .col-4 {
        width: 25%; }


.five-columns        { padding-left: 4em; }
.five-columns .col-1 { margin-left: -4em; }

    .five-columns .col-1,
    .five-columns .col-2,
    .five-columns .col-3,
    .five-columns .col-4,
    .five-columns .col-5 {
        width: 20%; }
