<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">

{% load i18n %}
{% load foneastratags %}

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en">
	<head>
		<title>{% block title %}FoneAstra{% endblock %}</title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />

{% block stylesheets %}
<link type="text/css" rel="stylesheet" href="/static/fa/stylesheets/splits.css" />
<link type="text/css" rel="stylesheet" href="/static/fa/stylesheets/modules.css" />
<link type="text/css" rel="stylesheet" href="/static/fa/stylesheets/tables.css" />
<link type="text/css" rel="stylesheet" href="/static/fa/stylesheets/forms.css" />
<link type="text/css" rel="stylesheet" href="/static/fa/stylesheets/icons.css" />
<link type="text/css" rel="stylesheet" href="/static/fa/stylesheets/foneastra.css" />
{% endblock %}

{% block javascripts %}
{% endblock %}

        <style>
        {% block inlinestyles %}
        {% endblock %}
        </style>

	</head>
	<body>
		<div id="wrapper">
			{% block header %}
			<div id="header">
				<div id="branding">
					<h1>
						<a title="{% trans "Return to the Dashboard" %}" href="{% url foneastra-home %}">
							<span>FoneAstra</span>
						</a>
					</h1>
				</div>

				{% block auth %}
				<div id="auth">{% if user.is_authenticated %}
					<a href="/fa/logout">{% trans "Log out" %} {{ user.username }}</a>{% else %}
					<a href="/fa/login">{% trans "Log in" %}</a>{% endif %}
				</div>
				{% endblock %}

                {% block page_tabs %}
                {% find_all_fa_apps as apps %}
                <ul id="tabs">
                    {% for app_url, app_name in apps %}
                        <li class="page"><a href="{{ app_url }}">{{ app_name }}</a></li>
                    {% endfor %}
                </ul>
                {% endblock %}
			</div>
			{% endblock %}

			<div id="inner">
				{% block content %}{% endblock %}
			</div>

			{% block footer %}
                {% if USE_I18N %}
                    <form action="/i18n/setlang/" method="post" style="float:right">
                    <select name="language">
                    {% for lang in LANGUAGES %}
                    <option value="{{ lang.0 }}"
                    {% ifequal LANGUAGE_CODE lang.0 %}selected{% endifequal %}>
                    {{ lang.1 }}
                    </option>
                    {% endfor %}
                    </select>
                    <input type="submit" class="small" value="Submit"/>
                    </form>
                {% endif %}

                <div id="footer">
                    <p class="rights">
                        {% trans "Powered by Django" %}<br />
                    </p>
                </div>
            {% endblock %}
		</div>
	</body>
</html>
