/* vim:set et ts=4 sw=4 */

div.module {
    margin-top: 2em;
    position: relative;
}

    div.module div.module {
        border: 1px solid #8fbcc9; }

div.module:first-child {
    margin-top: 0; }




div.module.collapsed {
    overflow-y: hidden;
    height: 2.6em;
}

    div.module.collapsed h2 {
        background-image: url("../images/h2-bg-collapsed.png"); }

    div.module.collapsed + div.module {
        margin-top: 1px; }

    div.module.collapsed h2 span.toggler,
    div.module.expanded h2 span.toggler {
        background: no-repeat 50% 50%;
        text-indent: -9999px;
        cursor: pointer;
        width: 16px;
        height: 2.6em;
        overflow: hidden;
        position: absolute;
        padding: 0 0.5em;
        right: 0;
        top: 0;
    }

        div.module.collapsed h2 span.toggler { background-image: url("../icons/silk/section_collapsed--bright.png"); }
        div.module.expanded  h2 span.toggler { background-image: url("../icons/silk/section_expanded--bright.png"); }




/* module headers are mostly ripped off from  django admin, although
 * here, we never use <caption>, to keep things simple. (they have
 * surprisingly confusing layout rules.) */
div.module h2,
div.module h3 {
    margin: 0;
    background-repeat: repeat-x;
    background-position: 0 100%;
    white-space: nowrap;
    font-weight: normal;
    line-height: 1;
    color: #fff;
}

    div.module h2 {
        background-color: #000;
        background-image: url("../images/h2-bg.png");
        text-shadow: #000 2px 2px 1px;
        padding: 0.3125em;
        font-size: 160%;
    }

        /* less important info can  be wrapped in a span to dull it */
        div.module h2 span {
            text-shadow: none;
            font-size: 62.5%;
            opacity: 0.8;
        }

    /* subheaders are almost the same. to dull things, i just made the
     * h2-bg image 80% opaque and re-saved it. STILL TODO: ask meghana
     * to make this pretty */
    div.module h3 {
        background-image: url("../images/h3-bg.png");
        background-color: #333;
        padding: 0.5em;
        font-size: 100%;
    }




/* modules can (optionally) include help text, to explain how they can
 * be used. this is hidden by module-help.js, if it's available, but
 * shouldn't be too verbose, in case it isn't */
div.module div.help,
div.module form.search {
    border-right: 0.5em solid #ffb;
    border-left: 0.5em solid #ffb;
    background: #ffc;
    padding: 1em;
}

    div.module div.help p {
        margin: 0; }


/* modules can optionally contain a small "toolbar", which hangs in the
 * top right, overlapping the <h2>, if there is one */
div.module div.toolbar {
    position: absolute;
    top: 0;
    right: 0;
    line-height: 2.6em;
}

    div.module div.toolbar a,
    div.module div.toolbar span {
        display: block;
        float: right;
        color: #eee;
        margin-right: 0.625em;
        padding-left: 21px;
        background-repeat: no-repeat;
        background-position: 0 50%;
        font-size: 80%;
        cursor: pointer;
    }

        /* various common toolbar icons. should be from the famfamfam
         * silk set, to fit in with the rest of RapidSMS. this will
         * probably grow (and be abstracted) as apps do more things */
        div.module div.toolbar .add    { background-image: url("../icons/silk/add.png");       }
        div.module div.toolbar .help   { background-image: url("../icons/silk/help.png");      }
        div.module div.toolbar .search { background-image: url("../icons/silk/magnifier.png"); }
