{% extends "fa/foneastra_base.html" %}

{% block content %}
<div class="two-columns">
    <div class="col-1">
        {% block left %}{% endblock %}
    </div>
    <div class="col-2">
        {% block right %}{% endblock %}
    </div>
    <div class="clear-hack"></div>
</div>
{% endblock %}


